<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Deduction;
use App\Employee;
use App\Historique;

class DeductionController extends Controller
{
    public function __construct()
    {
        $this->middleware(['auth', 'isAdmin']); //isAdmin middleware lets only users with a //specific permission permission to access these resources
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $deductions = Deduction::all();

        return view('deductions.index')->with('deductions', $deductions);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //return view('deductions.create');
    }

    public function getEmployee()
    {
        $employees = Employee::all(); //Get all employees

        return view('deductions.checkemployee', compact('employees'));
    }

    public function addDeduction($id)
    {
        $employee = Employee::findOrFail($id);

        $name = $employee->name.' '.$employee->firstname;

        return view('deductions.create', compact('employee', 'id', 'name'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'employee_name' => 'required',
        ]);

        $deduction = new Deduction();

        $deduction->employee_id = $request->input('employee_id');

        $employee = Employee::findOrFail($deduction->employee_id);

        $deduction->employee_name = $employee->name;
        $deduction->employee_firstname = $employee->firstname;
        $deduction->employee_email = $employee->email;
        $deduction->employee_phone = $employee->phone_number;
        $deduction->employee_address = $employee->address;
        $deduction->reason = $request->input('reason');
        $deduction->deduction_amount = $request->input('deduction_amount');
        $deduction->year = $request->input('year');
        $deduction->month = $request->input('month');
        $deduction->status = $request->input('status');
        $deduction->deduction_comment = $request->input('deduction_comment');
        $deduction->user_id = auth()->user()->id;

        $historique = new Historique();
        $historique->action = 'Create';
        $historique->table = 'Deduction';
        $historique->user_id = auth()->user()->id;

        $deduction->save();
        $historique->save();

        //Redirect to the deeds.index view and display message
        return redirect()->route('deductions.index')
            ->with('success',
             'Déduction ajouté avec succès.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $deduction = Deduction::findOrFail($id); //Get deduction with specified id

        return view('deductions.show', compact('deduction')); //pass deductiondata to view
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $deduction = Deduction::findOrFail($id); //Get deduction with specified id

        $employee = Employee::findOrFail($deduction->employee_id);

        $name = $employee->name.' '.$employee->firstname;

        return view('deductions.edit', compact('deduction', 'employee', 'name')); //pass deduction data to view
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $deduction = Deduction::findOrFail($id);
        
        $this->validate($request, [
            'employee_name' => 'required',
        ]);

        $employee = Employee::findOrFail($deduction->employee_id);

        $deduction->employee_name = $employee->name;
        $deduction->employee_firstname = $employee->firstname;
        $deduction->employee_email = $employee->email;
        $deduction->employee_phone = $employee->phone_number;
        $deduction->employee_address = $employee->address;
        $deduction->reason = $request->input('reason');
        $deduction->deduction_amount = $request->input('deduction_amount');
        $deduction->year = $request->input('year');
        $deduction->month = $request->input('month');
        $deduction->status = $request->input('status');
        $deduction->deduction_comment = $request->input('deduction_comment');
        $deduction->user_id = auth()->user()->id;

        $historique = new Historique();
        $historique->action = 'Update';
        $historique->table = 'Deduction';
        $historique->user_id = auth()->user()->id;

        $deduction->save();
        $historique->save();

        //Redirect to the deeds.index view and display message
        return redirect()->route('deductions.index')
            ->with('success',
             'Déduction édité avec succès.');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $deduction = Deduction::findOrFail($id);
        
        $historique = new Historique();
        $historique->action = 'Delete';
        $historique->table = 'Deduction';
        $historique->user_id = auth()->user()->id;

        $deduction->delete();
        $historique->save();

        return redirect()->route('deductions.index')
            ->with('success',
             'Deduction supprimé avec succès.');
    }
}
