<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Deed;
use App\TypeContract;
use App\Employee;
use App\Historique;

class DeedController extends Controller
{
    public function __construct()
    {
        $this->middleware(['auth', 'isAdmin']); //isAdmin middleware lets only users with a //specific permission permission to access these resources
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $deeds = Deed::all();

        return view('deeds.index')->with('deeds', $deeds);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        /* $typecontracts = TypeContract::pluck('title', 'id');

        return view('deeds.create', compact('typecontracts')); */
    }

    public function getEmployee()
    {
        $employees = Employee::all(); //Get all employees

        return view('deeds.checkemployee', compact('employees'));
    }

    public function addDeed($id)
    {
        $employee = Employee::findOrFail($id);

        $typecontracts = TypeContract::pluck('title', 'id');

        $name = $employee->name.' '.$employee->firstname;

        return view('deeds.create', compact('employee', 'typecontracts', 'id', 'name'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'start_date' => 'required',
        ]);

        $deed = new Deed();

        $deed->employee_id = $request->input('employee_id');
        

        $employee = Employee::findOrFail($deed->employee_id);
        $deed->employee_name = $employee->name;
        $deed->employee_firstname = $employee->firstname;
        $deed->employee_email = $employee->email;
        $deed->employee_phone = $employee->phone_number;
        $deed->employee_address = $employee->address;

        $deed->typeContract_id= $request->input('typeContract_id');

        $typecontract = TypeContract::findOrFail($deed->typeContract_id);
        
        $deed->typeContract_title = $typecontract->title;
        $deed->start_date= $request->input('start_date');
        $deed->end_date = $request->input('end_date');
        $deed->status = $request->input('status');
        $deed->hire_comment = $request->input('hire_comment');
        $deed->user_id = auth()->user()->id;
        //$deed->user_id = auth()->user()->id;

        $historique = new Historique();
        $historique->action = 'Create';
        $historique->table = 'Deed';
        $historique->user_id = auth()->user()->id;

        $deed->save();
        $historique->save();

        //Redirect to the deeds.index view and display message
        return redirect()->route('deeds.index')
            ->with('success',
             'Contrat ajouté avec succès.');

    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $deed = Deed::findOrFail($id); //Get deed with specified id

        return view('deeds.show', compact('deed')); //pass deed data to view
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $typecontracts = TypeContract::pluck('title', 'id');
        
        $deed = Deed::findOrFail($id); //Get deed with specified id

        $employee = Employee::findOrFail($deed->employee_id);

        $name = $employee->name.' '.$employee->firstname;

        return view('deeds.edit', compact('deed', 'typecontracts', 'employee', 'name')); //pass deed data to view
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $deed = Deed::findOrFail($id);

        $this->validate($request, [
            'employee_name' => 'required',
        ]);

        $employee = Employee::findOrFail($deed->employee_id);
        $deed->employee_name = $employee->name;
        $deed->employee_firstname = $employee->firstname;
        $deed->employee_email = $employee->email;
        $deed->employee_phone = $employee->phone_number;
        $deed->employee_address = $employee->address;

        $deed->typeContract_id= $request->input('typeContract_id');

        $typecontract = TypeContract::findOrFail($deed->typeContract_id);
        
        $deed->typeContract_title = $typecontract->title;
        $deed->start_date= $request->input('start_date');
        $deed->end_date = $request->input('end_date');
        $deed->status = $request->input('status');
        $deed->hire_comment = $request->input('hire_comment');
        $deed->user_id = auth()->user()->id;

        $historique = new Historique();
        $historique->action = 'Update';
        $historique->table = 'Deed';
        $historique->user_id = auth()->user()->id;

        $deed->save();
        $historique->save();

        //Redirect to the deeds.index view and display message
        return redirect()->route('deeds.index')
            ->with('success',
             'Contrat édité avec succès.');

    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $deed = Deed::findOrFail($id);
        
        $historique = new Historique();
        $historique->action = 'Delete';
        $historique->table = 'Deed';
        $historique->user_id = auth()->user()->id;

        $deed->delete();
        $historique->save();

        return redirect()->route('deeds.index')
            ->with('success',
             'Contrat supprimé avec succès.');
    }
}
