<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Historique;
use App\Employee;
use App\Department;
use App\TypeContract;
use App\Agreement;

class EmployeeController extends Controller
{
    public function __construct()
    {
        $this->middleware(['auth', 'isAdmin']); //isAdmin middleware lets only users with a //specific permission permission to access these resources
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //Get all employees and pass it to the view
        $employees = Employee::all();

        $departments = Department::pluck('name', 'id');

        return view('employees.index', compact('employees', 'departments'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $departments = Department::pluck('name', 'id');

        return view('employees.create', compact('departments'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //Validate name, email and password fields
        $this->validate($request, [
            'name' => 'required|max:120',
            'firstname' => 'required|max:120',
            'email' => 'required|email|unique:employees',
            'phone_number' => 'required',
            'address' => 'required',
            'profile_picture' => 'image|nullable',
        ]);

        if ($request->hasfile('profile_picture')) {
            // Get filename with the extension
            $fileNameWithExt = $request->file('profile_picture')->getClientOriginalName();

            // Get just filename
            $filename = pathinfo($fileNameWithExt, PATHINFO_FILENAME);

            // Get just ext
            $extension = $request->file('profile_picture')->getClientOriginalExtension();

            // Filename to store
            $fileNameToStore = $filename.'_'.time().'.'.$extension;

            // Upload Image
            $path = $request->file('profile_picture')->storeAs('public/profile_images', $fileNameToStore);
        } else {
            $fileNameToStore = 'noimage.jpg';
        }

        $employee = new Employee();
        $employee->name = $request->input('name');
        $employee->firstname = $request->input('firstname');
        $employee->email = $request->input('email');
        $employee->position = $request->input('position');
        $employee->profile_picture = $fileNameToStore;
        $employee->phone_number = $request->input('phone_number');
        $employee->address = $request->input('address');
        $employee->age = $request->input('age');
        $employee->birthdate = $request->input('birthdate');
        $employee->place_birth = $request->input('place_birth');
        $employee->gender = $request->input('gender');
        $employee->date_hired = $request->input('date_hired');
        $employee->department_id = $request->input('department_id');


        $department = Department::findOrFail($employee->department_id);

        $employee->department_name = $department->name;

        $employee->insurance = $request->input('insurance');
        $employee->marital_status = $request->input('marital_status');
        $employee->status = 1;
        $employee->user_id = auth()->user()->id;

        $historique = new Historique();
        $historique->action = 'Create';
        $historique->table = 'Employee';
        $historique->user_id = auth()->user()->id;

        $employee->save();
        $historique->save();

        //Redirect to the employees.index view and display message
        return redirect()->route('employees.index')
            ->with('success',
             'Nouvel Employé ajouté avec succès.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $departments = Department::pluck('name', 'id');

        $employee = Employee::findOrFail($id); //Get employee with specified id

        return view('employees.show', compact('employee','departments')); //pass employee data to view
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $departments = Department::pluck('name', 'id');

        $employee = Employee::findOrFail($id); //Get employee with specified id

        return view('employees.edit', compact('employee','departments')); //pass employee data to view
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $employee = Employee::findOrFail($id); //Get role specified by id

        //Validate name, email and password fields
        $this->validate($request, [
            'name' => 'required|max:120',
            'firstname' => 'required|max:120',
            'email' => 'required|email|unique:employees,email,'.$id,
            'phone_number' => 'required',
            'address' => 'required',
            'profile_picture' => 'image|nullable',
        ]);

        if ($request->hasfile('profile_picture')) {
            // Get filename with the extension
            $fileNameWithExt = $request->file('profile_picture')->getClientOriginalName();

            // Get just filename
            $filename = pathinfo($fileNameWithExt, PATHINFO_FILENAME);

            // Get just ext
            $extension = $request->file('profile_picture')->getClientOriginalExtension();

            // Filename to store
            $fileNameToStore = $filename.'_'.time().'.'.$extension;

            // Upload Image
            $path = $request->file('profile_picture')->storeAs('public/profile_images', $fileNameToStore);
        } else {
            $fileNameToStore = 'noimage.jpg';
        }

        $employee->name = $request->input('name');
        $employee->firstname = $request->input('firstname');
        $employee->email = $request->input('email');
        $employee->position = $request->input('position');
        $employee->phone_number = $request->input('phone_number');
        $employee->address = $request->input('address');

        if ($request->hasfile('profile_picture')) {
            $employee->profile_picture = $fileNameToStore;
        }

        $employee->age = $request->input('age');
        $employee->birthdate = $request->input('birthdate');
        $employee->place_birth = $request->input('place_birth');
        $employee->gender = $request->input('gender');
        $employee->date_hired = $request->input('date_hired');
        $employee->department_id = $request->input('department_id');


        $department = Department::findOrFail($employee->department_id);

        $employee->department_name = $department->name;

        $employee->insurance = $request->input('insurance');
        $employee->marital_status = $request->input('marital_status');
        $employee->status = 1;
        $employee->user_id = auth()->user()->id;

        $historique = new Historique();
        $historique->action = 'Update';
        $historique->table = 'Employee';
        $historique->user_id = auth()->user()->id;

        $employee->save();
        $historique->save();

        //Redirect to the employees.index view and display message
        return redirect()->route('employees.index')
            ->with('success',
             'Employé '.$employee->name.' édité avec succès.');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $employee = Employee::findOrFail($id);
        
        $historique = new Historique();
        $historique->action = 'Delete';
        $historique->table = 'Employee';
        $historique->user_id = auth()->user()->id;

        $employee->delete();
        $historique->save();

        return redirect()->route('employees.index')
            ->with('success',
             'Employé supprimé avec succès.');
    }
}
