<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\TypeIncident;
use App\Employee;
use App\Incident;
use Carbon\Carbon;
use App\Historique;

class IncidentController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //Get all typeincidents and pass it to the view 
        $incidents = Incident::all();

        return view('incidents.index')->with('incidents', $incidents);
    }

    public function getEmployee()
    {
        $employees = Employee::all(); //Get all employees

        return view('incidents.checkemployee', compact('employees'));
    }


    public function addIncident($id)
    {
        $employee = Employee::findOrFail($id);

        $name = $employee->name.' '.$employee->firstname;

        $typeincidents = TypeIncident::pluck('name', 'id');

        $date = Carbon::now();

        return view('incidents.create', compact('employee', 'id', 'name', 'date','typeincidents'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        /* $typeincidents = TypeIncident::pluck('name', 'id');

        $date = Carbon::now();

        return view('incidents.create', compact('typeincidents', 'date')); */
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
         //Validate name, email and password fields
         $this->validate($request, [
            'date_incident' => 'required',
            'duration' => 'required',
        ]);

        $incident = new Incident();
        $incident->employee_id = $request->input('employee_id');
        $employee = Employee::findOrFail($incident->employee_id);

        $incident->employee_name = $employee->name;
        $incident->employee_firstname = $employee->firstname;
        $incident->incident_name = $request->input('incident_name');
        $incident->typeIncident_id = $request->input('typeIncident_id');
        
        $typeincident = TypeIncident::findOrFail($incident->typeIncident_id);

        $incident->typeIncident_name = $typeincident->name;

        $incident->date_incident= $request->input('date_incident');
        $incident->duration = $request->input('duration');
        $incident->description = $request->input('description');
        $incident->status = $request->input('status');
        $incident->user_id = auth()->user()->id;

        $historique = new Historique();
        $historique->action = 'Create';
        $historique->table = 'Incident';
        $historique->user_id = auth()->user()->id;

        $incident->save();
        $historique->save();

        //Redirect to the salaries.index view and display message
        return redirect()->route('incidents.index')
            ->with('success',
             'Incident ajouté avec succès.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $typeincidents = TypeIncident::pluck('name', 'id');

        $incident = Incident::findOrFail($id); //Get incident with specified id

        $employee = Employee::findOrFail($incident->employee_id);

        $name = $employee->name.' '.$employee->firstname;

        return view('incidents.edit', compact('incident', 'typeincidents', 'employee', 'name')); //pass incident data to view
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $incident = Incident::findOrFail($id);

        $this->validate($request, [
            'date_incident' => 'required',
            'duration' => 'required',
        ]);

        $employee = Employee::findOrFail($incident->employee_id);

        $incident->employee_name = $employee->name;
        $incident->employee_firstname = $employee->firstname;
        $incident->incident_name = $request->input('incident_name');
        $incident->typeIncident_id = $request->input('typeIncident_id');
        
        $typeincident = TypeIncident::findOrFail($incident->typeIncident_id);

        $incident->typeIncident_name = $typeincident->name;

        $incident->date_incident= $request->input('date_incident');
        $incident->duration = $request->input('duration');
        $incident->description = $request->input('description');
        $incident->status = $request->input('status');
        $incident->user_id = auth()->user()->id;

        $historique = new Historique();
        $historique->action = 'Update';
        $historique->table = 'Incident';
        $historique->user_id = auth()->user()->id;

        $incident->save();
        $historique->save();

        //Redirect to the salaries.index view and display message
        return redirect()->route('incidents.index')
            ->with('success',
             'Incident édité avec succès.');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $incident = Incident::findOrFail($id);
        
        $historique = new Historique();
        $historique->action = 'Delete';
        $historique->table = 'Incident';
        $historique->user_id = auth()->user()->id;

        $incident->delete();
        $historique->save();

        return redirect()->route('incidents.index')
            ->with('success',
             'Incident supprimé avec succès.');
    }
}
