<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Salary;
use App\Employee;
use App\Historique;
use Carbon\Carbon;
use PDF;

class SalaryController extends Controller
{
    public function __construct()
    {
        $this->middleware(['auth', 'isAdmin']); //isAdmin middleware lets only users with a //specific permission permission to access these resources
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $salaries = Salary::all();

        return view('salaries.index', compact('salaries'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //return view('salaries.create');
    }

    public function getEmployee()
    {
        $employees = Employee::all(); //Get all employees

        return view('salaries.checkemployee', compact('employees'));
    }


    public function addSalary($id)
    {
        $employee = Employee::findOrFail($id);

        $name = $employee->name.' '.$employee->firstname;

        return view('salaries.create', compact('employee', 'id', 'name'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //Validate name, email and password fields
        $this->validate($request, [
            'year' => 'required',
            'month' => 'required',
        ]);

        $salary = new Salary();
        $salary->employee_id = $request->input('employee_id');

        $employee = Employee::findOrFail($salary->employee_id);

        $salary->employee_name = $employee->name;
        $salary->employee_firstname = $employee->firstname;
        $salary->employee_email = $employee->email;
        $salary->employee_phone = $employee->phone_number;
        $salary->employee_address = $employee->address;

        $salary->salary_net = $request->input('salary_net');
        $salary->year = $request->input('year');
        $salary->month = $request->input('month');
        $salary->seniority_bonus = $request->input('seniority_bonus');
        $salary->risk_bonus = $request->input('risk_bonus');
        $salary->allowance = $request->input('allowance');
        $salary->conveyance = $request->input('conveyance');

        $salary->employee_salary = $salary->salary_net + $salary->seniority_bonus + $salary->risk_bonus + $salary->allowance + $salary->conveyance ;
        $salary->status = $request->input('status');
        $salary->user_id = auth()->user()->id;

        $historique = new Historique();
        $historique->action = 'Create';
        $historique->table = 'Salary';
        $historique->user_id = auth()->user()->id;

        $salary->save();
        $historique->save();

        //Redirect to the salaries.index view and display message
        return redirect()->route('salaries.index')
            ->with('success',
             'Salaire payé avec succès.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $employee = Employee::findOrFail($id);

        $date = Carbon::now();
        
        //$salary = Salary::findOrFail($id); //Get salary with specified id

        return view('salaries.show', compact('employee', 'date'))->with('salaries', $employee->salaries); //pass salaries data to view
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $salary = Salary::findOrFail($id); //Get salary with specified id

        $employee = Employee::findOrFail($salary->employee_id);

        $name = $employee->name.' '.$employee->firstname;

        return view('salaries.edit', compact('salary', 'employee', 'name')); //pass salary data to view
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $salary = Salary::findOrFail($id);
        //Validate name, email and password fields
        $this->validate($request, [
            'year' => 'required',
            'month' => 'required',
        ]);

        $employee = Employee::findOrFail($salary->employee_id);
        $salary->employee_name = $employee->name;
        $salary->employee_firstname = $employee->firstname;
        $salary->employee_email = $employee->email;
        $salary->employee_phone = $employee->phone_number;
        $salary->employee_address = $employee->address;

        $salary->salary_net = $request->input('salary_net');
        $salary->year = $request->input('year');
        $salary->month = $request->input('month');
        $salary->seniority_bonus = $request->input('seniority_bonus');
        $salary->risk_bonus = $request->input('risk_bonus');
        $salary->allowance = $request->input('allowance');
        $salary->conveyance = $request->input('conveyance');
        $salary->employee_salary = $salary->salary_net + $salary->seniority_bonus + $salary->risk_bonus + $salary->allowance + $salary->conveyance ;
        $salary->status = $request->input('status');
        $salary->user_id = auth()->user()->id;

        $historique = new Historique();
        $historique->action = 'Update';
        $historique->table = 'Salary';
        $historique->user_id = auth()->user()->id;

        $salary->save();
        $historique->save();

        //Redirect to the salaries.index view and display message
        return redirect()->route('salaries.index')
            ->with('success',
             'Salaire édité avec succès.');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $salary = Salary::findOrFail($id);
        
        $historique = new Historique();
        $historique->action = 'Delete';
        $historique->table = 'Salary';
        $historique->user_id = auth()->user()->id;

        $salary->delete();
        $historique->save();

        return redirect()->route('salaries.index')
            ->with('success',
             'Salaire supprimé avec succès.');
    }

    public function pdfexport($id)
    {
        $employee = Employee::findOrFail($id);

        $date = Carbon::now();

        $salaries = $employee->salaries;

        $data = ['employee' => $employee,
                 'salaries' => $salaries,
                 'date' => $date,
        ];

        $pdf = PDF::loadView('salaries.payslip', $data);

        return $pdf->download('payslip_'.$employee->name.'.pdf');
    }
}
