<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\TypeContract;
use App\Historique;

class TypecontractController extends Controller
{
    public function __construct()
    {
        $this->middleware(['auth', 'isAdmin']); //isAdmin middleware lets only users with a //specific permission permission to access these resources
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //Get all typecontracts and pass it to the view 
        $typecontracts = TypeContract::all();

        return view('typecontracts.index')->with('typecontracts', $typecontracts);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('typecontracts.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'title' => 'required',
            'duration' => 'required',
        ]);

        $typecontract = new TypeContract();
        $typecontract->title = $request->input('title');
        $typecontract->description = $request->input('description');
        $typecontract->duration = $request->input('duration');

        $historique = new Historique();
        $historique->action = 'Create';
        $historique->table = 'TypeContract';
        $historique->user_id = auth()->user()->id;

        $typecontract->save();
        $historique->save();

        //Redirect to the typecontracts.index view and display message
        return redirect()->route('typecontracts.index')
            ->with('success',
             'Nouveau Type de Contrat ajouté avec succès.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $typecontract = TypeContract::findOrFail($id); //Get typecontract with specified id

        return view('typecontracts.edit', compact('typecontract')); //pass typecontract data to view
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $typecontract = TypeContract::findOrFail($id); //Get typecontract with specified id

        $this->validate($request, [
            'title' => 'required',
            'duration' => 'required',
        ]);

        $typecontract->title = $request->input('title');
        $typecontract->description = $request->input('description');
        $typecontract->duration = $request->input('duration');

        $historique = new Historique();
        $historique->action = 'Update';
        $historique->table = 'TypeContract';
        $historique->user_id = auth()->user()->id;

        $typecontract->save();
        $historique->save();

        //Redirect to the typecontracts.index view and display message
        return redirect()->route('typecontracts.index')
            ->with('success',
             'Type de Contrat '.$typecontract->title.' édité avec succès.');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $typecontract = TypeContract::findOrFail($id);
        
        $historique = new Historique();
        $historique->action = 'Delete';
        $historique->table = 'TypeContract';
        $historique->user_id = auth()->user()->id;

        $typecontract->delete();
        $historique->save();

        return redirect()->route('typecontracts.index')
            ->with('success',
             'Type de Contrat supprimé avec succès.');
    }
}
