<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\TypeIncident;
use App\Historique;

class TypeincidentController extends Controller
{
    public function __construct()
    {
        $this->middleware(['auth', 'isAdmin']); //isAdmin middleware lets only users with a //specific permission permission to access these resources
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //Get all typeincidents and pass it to the view 
        $typeincidents = TypeIncident::all();

        return view('typeincidents.index')->with('typeincidents', $typeincidents);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('typeincidents.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'name' => 'required',
        ]);

        $typeincident = new TypeIncident();
        $typeincident->name = $request->input('name');
        $typeincident->description = $request->input('description');
        $typeincident->user_id = auth()->user()->id;

        $historique = new Historique();
        $historique->action = 'Create';
        $historique->table = 'TypeIncident';
        $historique->user_id = auth()->user()->id;

        $typeincident->save();
        $historique->save();

        //Redirect to the typeincidents.index view and display message
        return redirect()->route('typeincidents.index')
            ->with('success',
             'Nouveau Type Incident ajouté avec succès.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $typeincident = TypeIncident::findOrFail($id); //Get typeincident with specified id

        return view('typeincidents.edit', compact('typeincident')); //pass typeincident data to view
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $typeincident = TypeIncident::findOrFail($id);

        $this->validate($request, [
            'name' => 'required',
        ]);

        $typeincident->name = $request->input('name');
        $typeincident->description = $request->input('description');
        $typeincident->user_id = auth()->user()->id;

        $historique = new Historique();
        $historique->action = 'Update';
        $historique->table = 'TypeIncident';
        $historique->user_id = auth()->user()->id;

        $typeincident->save();
        $historique->save();

        //Redirect to the typeincidents.index view and display message
        return redirect()->route('typeincidents.index')
            ->with('success',
             'Type Incident édité avec succès.');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $typeincident = TypeIncident::findOrFail($id);
        
        $historique = new Historique();
        $historique->action = 'Delete';
        $historique->table = 'TypeIncident';
        $historique->user_id = auth()->user()->id;

        $typeincident->delete();
        $historique->save();

        return redirect()->route('typeincidents.index')
            ->with('success',
             'Type Incident supprimé avec succès.');
    }
}
